import React, { useState } from "react";
import { Button, Card } from "react-bootstrap";
import CustomButton from "../components/Button";
import { itemsState } from "../types/itemTypes";

interface Props {
    items: any[]
    btnFunction1: (event: any) => void;
    btnFunction2: (event: any) => void;
    btnText1: string;
    btnText2: string;
    showBtn?: boolean;
    showItemImage?: boolean;
    showItemName?: boolean;
    showItemPrice?: boolean;
}

export const CartView = ({ items, btnFunction1, btnFunction2, btnText1, btnText2, showBtn, showItemName, showItemPrice, showItemImage }: Props) => {

    console.log("miniapp-items", items)
    return (
        <div className="d-flex flex-wrap w-100">
            {
                items[0][0][0].map((product: itemsState) =>
                    <Card
                        className="d-flex bg-white shadow-sm m-2 col-2 p-1"
                        style={{ minWidth: "30%" }}
                        key={product.id}>
                        {
                            showItemImage != false &&
                            <Card.Img
                                className="p-1"
                                variant="top"
                                src={product.img}
                                height="100px"
                                width="100px"
                                style={{ objectFit: "contain" }}
                            />
                        }
                        <Card.Body
                            className={`${showBtn == false && showItemImage == false && showItemImage == false ? "flex-row" : "flex-column"} 
                                d-flex flex-column p-1`}>
                            {
                                showItemName != false || showItemPrice != false ?
                                    <Card.Title className={`d-flex flex-row justify-content-between my-3`}>
                                        {
                                            showItemName != false &&
                                            <span className="fs-.5">{product.name}</span>
                                        }
                                        {
                                            showItemPrice != false &&
                                            <span className="ms-2 text-muted">₱ {product.price}</span>
                                        }
                                    </Card.Title>
                                    : null
                            }

                            <div className="d-flex flex-row justify-content-between align-items-center">
                                {
                                    showBtn != false &&
                                    <CustomButton text={btnText1} onClickFunction={btnFunction1} param={product} />
                                }
                                <span className="ml-4 mr-4 cart ">{product.quantity}</span>
                                {
                                    showBtn != false &&
                                    <CustomButton text={btnText2} onClickFunction={btnFunction2} param={product} />
                                }
                            </div>
                        </Card.Body >
                    </Card>
                )
            }
        </div>
    )
}

export default CartView

